For review: fix a bug in mercury_trace.c

Erwan Jahier Erwan.Jahier at irisa.fr
Thu Jul 16 03:24:38 AEST 1998


Fergus, if/when you are happy with that, could you please commit it ?
I don't think I can do it from here.

runtime/mercury_trace.c:
	Replace MR_trace_debugger by MR_trace_handler.

Index: mercury_trace.c
===================================================================
RCS file: /home/mercury1/repository/mercury/runtime/mercury_trace.c,v
retrieving revision 1.14
diff -u -r1.14 mercury_trace.c
--- mercury_trace.c	1998/07/03 02:35:33	1.14
+++ mercury_trace.c	1998/07/15 08:30:37
@@ -127,14 +127,14 @@
 
 	MR_copy_regs_to_saved_regs(max_mr_num);
 #ifdef MR_USE_EXTERNAL_DEBUGGER
-	if (MR_trace_debugger == MR_TRACE_EXTERNAL) {
+	if (MR_trace_handler == MR_TRACE_EXTERNAL) {
		MR_trace_event_external(layout, port, seqno, depth, path);
 	} else {
 		MR_trace_event_internal(cmd, layout, port, seqno, depth, path);
	}
 #else
 	/*
 	** We should get here only if MR_trace_debugger == MR_TRACE_INTERNAL.
 	** This is enforced by mercury_wrapper.c.
 	*/
 
@@ -148,15 +148,15 @@
 	Unsigned seqno, Unsigned depth, const char *path, int max_r_num)
 {
 #ifdef MR_USE_EXTERNAL_DEBUGGER
-	if (MR_trace_debugger == MR_TRACE_EXTERNAL) {
+	if (MR_trace_handler == MR_TRACE_EXTERNAL) {
		fatal_abort("trying to report an event to external debugger");
 	} else {
 		MR_trace_event_internal_report(layout,
 			port, seqno, depth, path);
 	}
 #else
 	/*
 	** We should get here only if MR_trace_debugger == MR_TRACE_INTERNAL.
 	** This is enforced by mercury_wrapper.c.
 	*/
 
@@ -127,14 +127,14 @@
 #else
 	/*
-	** We should get here only if MR_trace_debugger == MR_TRACE_INTERNAL.
+	** We should get here only if MR_trace_handler == MR_TRACE_INTERNAL.
 	** This is enforced by mercury_wrapper.c.
 	*/
@@ -148,15 +148,15 @@
 #else
 	/*
-	** We should get here only if MR_trace_debugger == MR_TRACE_INTERNAL.
+	** We should get here only if MR_trace_handler == MR_TRACE_INTERNAL.
 	** This is enforced by mercury_wrapper.c.
 	*/

-- 
R1.



More information about the developers mailing list